soapcw.line\_aware\_stat package
================================

Submodules
----------

soapcw.line\_aware\_stat.gen\_lookup module
-------------------------------------------

.. automodule:: soapcw.line_aware_stat.gen_lookup
   :members:
   :undoc-members:
   :show-inheritance:

soapcw.line\_aware\_stat.gen\_lookup\_python module
---------------------------------------------------

.. automodule:: soapcw.line_aware_stat.gen_lookup_python
   :members:
   :undoc-members:
   :show-inheritance:

soapcw.line\_aware\_stat.save\_lookup module
--------------------------------------------

.. automodule:: soapcw.line_aware_stat.save_lookup
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: soapcw.line_aware_stat
   :members:
   :undoc-members:
   :show-inheritance:
